@@ -62,12 +62,13 @@ class ImagePostModelAnalysis:
             return None
 
         # Replace predictions not in true labels with -1
-        modified_eval_predictions = self.replace_predictions(eval_labels_unique=np.unique(self.eval_labels),
-                                                             eval_predictions=self.eval_predictions.numpy())
+
+        # modified_eval_predictions = self.replace_predictions(eval_labels_unique=np.unique(self.eval_labels),
+        #                                                      eval_predictions=self.eval_predictions.numpy())
         try:
-            cm = confusion_matrix(self.eval_labels.cpu().numpy(), modified_eval_predictions)
+            cm = confusion_matrix(self.eval_labels.cpu().numpy(), self.eval_predictions.numpy())
         except:
-            cm = confusion_matrix(self.eval_labels, modified_eval_predictions)
+            cm = confusion_matrix(self.eval_labels, self.eval_predictions)
         self.diamond_collector["confusion matrix"] = cm
 
         # Create confusion matrix plot
