@@ -15,6 +15,12 @@ def run(images,
         is_post_model_analysis=True, image_post_model: ImagePostModelSpec = None,
         plot=True
         ):
+    # Tell a story
+    story = """Welcome to MadCat, the comprehensive machine learning and data analysis solution!
+    \nThis module is designed to streamline the entire process image classification models, 
+    \nfrom start to finish.
+    \nTo learn more about MadCat, visit https://github.com/amito-ds/chester.\n"""
+    print(story)
     diamond_collector = {}
 
     # load the data
@@ -34,6 +40,7 @@ def run(images,
 
     # augmentation
     if is_augment_data:
+        print("====> Augmenting data")
         if image_augmentation_info is None:
             image_augmentation_info = ImagesAugmentationInfo()
         image_data = ImageAugmentation(image_data, image_augmentation_info).run()
@@ -45,6 +52,7 @@ def run(images,
 
     # Training
     if not is_train_model:
+        print("====> Training a Model")
         return diamond_collector
     if image_models is None:
         image_models = ImageModels()
